Page 144 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 144

Home

    We've spoken to survivors during our missionary
    work during the last seven and one- half years in

    ae ta yowro4

    Mozambique and Angola. We have spoken to survivors
    of massacres, where Cuban troops walked into churches,
    took the Bible off the pulpit, threw it out the door, and
    said, 'OK, it's all over, just form a line, walk past the
    Bible, spit on the Bible and you can go free. If you do
    not spit, though, we will certainly kill you." And
    Christians in Angola had to make a choice sometimes,
    under the AK 47s of Cuban troops, whether to spit or
    die.

    The man backed by U. S. leaders to take over the
    government of South Africa is Nelson Mandela, a
    Communist terrorist and head of the African National

    Congress (ANC), a Communist dominated terrorist
    organization.

    That Mandela was a Communist was proven when he
    was arrested and tried for treason by the South African
    Government. During the trial, articles and documents in
    Mandela's own handwriting were submitted to the court.
    In an 18-page document Mandela stated, "The people of
    South Africa, led by the South African Communist Party
    will destroy capitalist society and build in its place
    socialism."”! In another document, entitled "Political

    Economy," Mandela wrote, "We communist party

    members are the most advanced revolutionaries in
    . 2

    modern history. . . ."

    Although many blacks held elected positions in South
    Africa, until the national elections in 1994, Mandela was

    139

    Babylon's War Against God

    Economy," Mandela wrote,

    never elected to any government position by his people.